# Integration Guides

Guides for integrating MCP Ticketer with various platforms and AI clients.

## AI Client Integration

- **[AI Client Integration](AI_CLIENT_INTEGRATION.md)** - Multi-client MCP setup and configuration
- **[Pull Request Integration](PR_INTEGRATION.md)** - GitHub PR automation and linking
- **[Attachments](ATTACHMENTS.md)** - Working with ticket attachments

## Platform Setup Guides

- **[Claude Desktop Setup](setup/CLAUDE_DESKTOP_SETUP.md)** - Claude Desktop integration
- **[Codex Integration](setup/CODEX_INTEGRATION.md)** - Codex CLI integration
- **[Linear Setup](setup/LINEAR_SETUP.md)** - Linear integration setup
- **[JIRA Setup](setup/JIRA_SETUP.md)** - JIRA integration setup

## See Also

- [User Documentation](../user-docs/README.md) - General usage guides
- [Developer Documentation](../developer-docs/README.md) - API and adapter development
- [Architecture Documentation](../architecture/README.md) - Integration architecture details
